Class StepExecutionRequestHandler
java.lang.Object
org.springframework.batch.integration.partition.StepExecutionRequestHandler
A
MessageEndpoint that can handle a StepExecutionRequest and return a
StepExecution as the result. Typically these need to be aggregated into a
response to a partition handler.- Author:
- Dave Syer
-
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionorg.springframework.batch.core.StepExecutionhandle(StepExecutionRequest request) voidsetJobExplorer(org.springframework.batch.core.explore.JobExplorer jobExplorer) An explorer that should be used to check forStepExecutioncompletion.voidsetStepLocator(org.springframework.batch.core.step.StepLocator stepLocator) Used to locate aStepto execute for each request.
-
Constructor Details
-
StepExecutionRequestHandler
public StepExecutionRequestHandler()
-
-
Method Details
-
setStepLocator
public void setStepLocator(org.springframework.batch.core.step.StepLocator stepLocator) Used to locate aStepto execute for each request.- Parameters:
stepLocator- aStepLocator
-
setJobExplorer
public void setJobExplorer(org.springframework.batch.core.explore.JobExplorer jobExplorer) An explorer that should be used to check forStepExecutioncompletion.- Parameters:
jobExplorer- aJobExplorerthat is linked to the shared repository used by all remote workers.
-
handle
@ServiceActivator public org.springframework.batch.core.StepExecution handle(StepExecutionRequest request)
-